// Data for nodes and links
const nodes = [
  { id: 'Netflix Catalog', group: 0 },
  { id: 'Dramas', group: 1 },
  { id: 'Comedies', group: 1 },
  { id: 'Action & Adventure', group: 1 },
  { id: 'Dramas - Movie', group: 2 },
  { id: 'Dramas - TV Show', group: 2 },
  { id: 'Comedies - Movie', group: 2 },
  { id: 'Comedies - TV Show', group: 2 },
  { id: 'Action & Adventure - Movie', group: 2 },
  { id: 'Action & Adventure - TV Show', group: 2 },
  // Movies and TV Shows
  { id: 'Sankofa', group: 3 },
  { id: 'Je Suis Karl', group: 3 },
  { id: 'The Crown', group: 3 },
  { id: 'Breaking Bad', group: 3 },
  { id: 'The Starling', group: 3 },
  { id: 'Avvai Shanmughi', group: 3 },
  { id: 'Brooklyn Nine-Nine', group: 3 },
  { id: 'The Good Place', group: 3 },
  { id: 'The Stronghold', group: 3 },
  { id: 'Birth of the Dragon', group: 3 },
  { id: 'Arrow', group: 3 },
  { id: 'Daredevil', group: 3 },
];

const links = [
  // Connect genres to the root node
  { source: 'Netflix Catalog', target: 'Dramas', value: 1 },
  {
    source: 'Netflix Catalog',
    target: 'Comedies',
    value: 1,
  },
  {
    source: 'Netflix Catalog',
    target: 'Action & Adventure',
    value: 1,
  },
  // Connect sub-genres to genres
  { source: 'Dramas', target: 'Dramas - Movie', value: 1 },
  {
    source: 'Dramas',
    target: 'Dramas - TV Show',
    value: 1,
  },
  {
    source: 'Comedies',
    target: 'Comedies - Movie',
    value: 1,
  },
  {
    source: 'Comedies',
    target: 'Comedies - TV Show',
    value: 1,
  },
  {
    source: 'Action & Adventure',
    target: 'Action & Adventure - Movie',
    value: 1,
  },
  {
    source: 'Action & Adventure',
    target: 'Action & Adventure - TV Show',
    value: 1,
  },
  // Connect titles to sub-genres
  { source: 'Dramas - Movie', target: 'Sankofa', value: 1 },
  {
    source: 'Dramas - Movie',
    target: 'Je Suis Karl',
    value: 1,
  },
  {
    source: 'Dramas - TV Show',
    target: 'The Crown',
    value: 1,
  },
  {
    source: 'Dramas - TV Show',
    target: 'Breaking Bad',
    value: 1,
  },
  {
    source: 'Comedies - Movie',
    target: 'The Starling',
    value: 1,
  },
  {
    source: 'Comedies - Movie',
    target: 'Avvai Shanmughi',
    value: 1,
  },
  {
    source: 'Comedies - TV Show',
    target: 'Brooklyn Nine-Nine',
    value: 1,
  },
  {
    source: 'Comedies - TV Show',
    target: 'The Good Place',
    value: 1,
  },
  {
    source: 'Action & Adventure - Movie',
    target: 'The Stronghold',
    value: 1,
  },
  {
    source: 'Action & Adventure - Movie',
    target: 'Birth of the Dragon',
    value: 1,
  },
  {
    source: 'Action & Adventure - TV Show',
    target: 'Arrow',
    value: 1,
  },
  {
    source: 'Action & Adventure - TV Show',
    target: 'Daredevil',
    value: 1,
  },
  // ... you can continue to add more links for other titles as needed
];

// Set the dimensions and margins of the graph
const width = 960;
const height = 600;

// Append the svg object to the body of the page
const svg = d3
  .select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

// Initialize the links
const link = svg
  .selectAll('.links')
  .data(links)
  .enter()
  .append('line')
  .style('stroke', '#aaa');

// Initialize the nodes
const node = svg
  .selectAll('.nodes')
  .data(nodes)
  .enter()
  .append('g');

node
  .append('circle')
  .attr('r', 10)
  .style('fill', (d) => {
    const colors = [
      '#FF5733',
      '#33FF57',
      '#3357FF',
      '#57FF33',
    ];
    return colors[d.group] || '#333';
  });

node
  .append('text')
  .text((d) => d.id)
  .attr('x', 12)
  .attr('y', 3);

// Let's list the force simulation
const simulation = d3
  .forceSimulation(nodes)
  .force(
    'link',
    d3
      .forceLink(links)
      .id((d) => d.id)
      .distance(50),
  )
  .force('charge', d3.forceManyBody().strength(-200))
  .force('center', d3.forceCenter(width / 2, height / 2))
  .on('tick', ticked);

function ticked() {
  link
    .attr('x1', (d) => d.source.x)
    .attr('y1', (d) => d.source.y)
    .attr('x2', (d) => d.target.x)
    .attr('y2', (d) => d.target.y);

  node.attr('transform', (d) => `translate(${d.x},${d.y})`);
}
